==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/labservices/kotlin/inputs/GetGlobalUserPersonalPreferencesPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.labservices.kotlin.inputs

import com.pulumi.azurenative.labservices.inputs.GetGlobalUserPersonalPreferencesPlainArgs.builder
import com.pulumi.azurenative.labservices.kotlin.enums.AddRemove
import com.pulumi.core.Either
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property addRemove Enum indicating if user is adding or removing a favorite lab
 * @property labAccountResourceId Resource Id of the lab account
 * @property labResourceId Resource Id of the lab to add/remove from the favorites list
 * @property userName The name of the user.
 */
public data class GetGlobalUserPersonalPreferencesPlainArgs(
    public val addRemove: Either<String, AddRemove>? = null,
    public val labAccountResourceId: String? = null,
    public val labResourceId: String? = null,
    public val userName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.labservices.inputs.GetGlobalUserPersonalPreferencesPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.labservices.inputs.GetGlobalUserPersonalPreferencesPlainArgs =
        com.pulumi.azurenative.labservices.inputs.GetGlobalUserPersonalPreferencesPlainArgs.builder()
            .addRemove(
                addRemove?.let({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .labAccountResourceId(labAccountResourceId?.let({ args0 -> args0 }))
            .labResourceId(labResourceId?.let({ args0 -> args0 }))
            .userName(userName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetGlobalUserPersonalPreferencesPlainArgs].
 */
@PulumiTagMarker
public class GetGlobalUserPersonalPreferencesPlainArgsBuilder internal constructor() {
    private var addRemove: Either<String, AddRemove>? = null

    private var labAccountResourceId: String? = null

    private var labResourceId: String? = null

    private var userName: String? = null

    /**
     * @param value Enum indicating if user is adding or removing a favorite lab
     */
    @JvmName("lsvdvyrheyboqmso")
    public suspend fun addRemove(`value`: Either<String, AddRemove>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.addRemove = mapped
    }

    /**
     * @param value Enum indicating if user is adding or removing a favorite lab
     */
    @JvmName("tfplwsgbpwuwmpod")
    public fun addRemove(`value`: String) {
        val toBeMapped = Either.ofLeft<String, AddRemove>(value)
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.addRemove = mapped
    }

    /**
     * @param value Enum indicating if user is adding or removing a favorite lab
     */
    @JvmName("jlhsgownvwadvpqt")
    public fun addRemove(`value`: AddRemove) {
        val toBeMapped = Either.ofRight<String, AddRemove>(value)
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.addRemove = mapped
    }

    /**
     * @param value Resource Id of the lab account
     */
    @JvmName("grvgjbctskkalvwb")
    public suspend fun labAccountResourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.labAccountResourceId = mapped
    }

    /**
     * @param value Resource Id of the lab to add/remove from the favorites list
     */
    @JvmName("hkprrbprolqthara")
    public suspend fun labResourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.labResourceId = mapped
    }

    /**
     * @param value The name of the user.
     */
    @JvmName("ufgrtgfgkqvwjsjv")
    public suspend fun userName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.userName = mapped
    }

    internal fun build(): GetGlobalUserPersonalPreferencesPlainArgs =
        GetGlobalUserPersonalPreferencesPlainArgs(
            addRemove = addRemove,
            labAccountResourceId = labAccountResourceId,
            labResourceId = labResourceId,
            userName = userName ?: throw PulumiNullFieldException("userName"),
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/labservices/kotlin/inputs/GetGlobalUserPersonalPreferencesPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.labservices.kotlin.inputs

import com.pulumi.azurenative.labservices.inputs.GetGlobalUserPersonalPreferencesPlainArgs.builder
import com.pulumi.azurenative.labservices.kotlin.enums.AddRemove
import com.pulumi.core.Either
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property addRemove Enum indicating if user is adding or removing a favorite lab
 * @property labAccountResourceId Resource Id of the lab account
 * @property labResourceId Resource Id of the lab to add/remove from the favorites list
 * @property userName The name of the user.
 */
public data class GetGlobalUserPersonalPreferencesPlainArgs(
    public val addRemove: Either<String, AddRemove>? = null,
    public val labAccountResourceId: String? = null,
    public val labResourceId: String? = null,
    public val userName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.labservices.inputs.GetGlobalUserPersonalPreferencesPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.labservices.inputs.GetGlobalUserPersonalPreferencesPlainArgs =
        com.pulumi.azurenative.labservices.inputs.GetGlobalUserPersonalPreferencesPlainArgs.builder()
            .addRemove(
                addRemove?.let({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .labAccountResourceId(labAccountResourceId?.let({ args0 -> args0 }))
            .labResourceId(labResourceId?.let({ args0 -> args0 }))
            .userName(userName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetGlobalUserPersonalPreferencesPlainArgs].
 */
@PulumiTagMarker
public class GetGlobalUserPersonalPreferencesPlainArgsBuilder internal constructor() {
    private var addRemove: Either<String, AddRemove>? = null

    private var labAccountResourceId: String? = null

    private var labResourceId: String? = null

    private var userName: String? = null

    /**
     * @param value Enum indicating if user is adding or removing a favorite lab
     */
    @JvmName("nkqcaylrenmibarl")
    public suspend fun addRemove(`value`: Either<String, AddRemove>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.addRemove = mapped
    }

    /**
     * @param value Enum indicating if user is adding or removing a favorite lab
     */
    @JvmName("mgsdkgldjtjiavye")
    public fun addRemove(`value`: String) {
        val toBeMapped = Either.ofLeft<String, AddRemove>(value)
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.addRemove = mapped
    }

    /**
     * @param value Enum indicating if user is adding or removing a favorite lab
     */
    @JvmName("oqmkukdojolictft")
    public fun addRemove(`value`: AddRemove) {
        val toBeMapped = Either.ofRight<String, AddRemove>(value)
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.addRemove = mapped
    }

    /**
     * @param value Resource Id of the lab account
     */
    @JvmName("xexpvnsgbcxtkpvv")
    public suspend fun labAccountResourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.labAccountResourceId = mapped
    }

    /**
     * @param value Resource Id of the lab to add/remove from the favorites list
     */
    @JvmName("srlgaxpdnsyjgyto")
    public suspend fun labResourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.labResourceId = mapped
    }

    /**
     * @param value The name of the user.
     */
    @JvmName("gaxwqvmqhyckrpse")
    public suspend fun userName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.userName = mapped
    }

    internal fun build(): GetGlobalUserPersonalPreferencesPlainArgs =
        GetGlobalUserPersonalPreferencesPlainArgs(
            addRemove = addRemove,
            labAccountResourceId = labAccountResourceId,
            labResourceId = labResourceId,
            userName = userName ?: throw PulumiNullFieldException("userName"),
        )
}
